Macros
- path_
scan path_scan!macro parses an input string using the provided patterns and returns a closure that yields the result of the first matching arm.- path_
scan_ val path_scan_val!macro parses an input string using the provided patterns and returns the result of the first matching arm directly.